# NAGINI-3D | Prediction of Parametric Surfaces for Multi-Object Segmentation in 3D Biological Imaging

We present NAGINI-3D (N-Active shapes for seGmentINg 3D biological Images), a method dedicated to 3D biological images segmentation, based on both deep learning (CNN) and Active Surfaces (Snakes).

This package implement the method described in:

- Quentin RAPILLY, Pierre MAINDRON, Guenaelle BOUET-CHALON, Anaïs BADOUAL, Charles KERVRANN.
[*Prediction of Parametric Surfaces for Multi-Object Segmentation in 3D Biological Imaging*](https://hal.science/hal-04978619). International Conference on Scale Space and Variational Methods in Computer Vision (SSVM), Totnes, England, May 2025.

All details on the implementation and the tutorials are available on [the github of the project.](https://github.com/QuentinRapilly/NAGINI-3D)
